; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a OpenStreetMap plot
; with Coyote Graphics routines. Information about the static MapLite API can
; be found on the `OpenStreetMap Wiki Page <http://wiki.openstreetmap.org/wiki/Static_map_images>`.
; Note that if you get "curl" errors when you try to access the Google web page, it may be 
; you have to use a proxy for the network. If so, you may have to modify the "netObject" variable in
; the code below with the name of your proxy server and its port number, like this::
;
;    netObject = Obj_New('IDLnetURL', PROXY_HOSTNAME="nameOfYourProxy", PROXY_PORT=yourPortNumber
;
; Other proxy keywords may also be required. See the on-line documentation of IDLnetURL for details.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "openstreetmap_plot.pro" and run it like this::
;       IDL> .RUN openstreetmap_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 14 February 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO OpenStreetMap_Plot
 
   ; Set up variables for the plot. Normally, these values would be
   ; passed into the program as positional and keyword parameters.
   ; Here we set the map up to view Barcelona, Spain.
   centerLat = 41.3857D
   centerLon = 2.1699D
   zoom = 12
   
   ; The OpenStreetMap and GoogleMap APIs are the same, so we can
   ; use cgGoogle_MetersPerPixel to find the scale for the map.
   scale = cgGoogle_MetersPerPixel(zoom)
   
   ; Gather the OpenStreetmap using the StaticLite Map API.
   mapStr = "http://staticmap.openstreetmap.de/staticmap.php?" + $
      "center=" + StrTrim(centerLat,2) + ',' + StrTrim(centerLon,2) + $
      "&zoom=" + StrTrim(zoom,2) + "&size=600x600" 
   netObject = Obj_New('IDLnetURL')
   void = netObject -> Get(URL=mapStr, FILENAME="barcelona.png")
   Obj_Destroy, netObject
   mapImage = Read_Image('barcelona.png') 
   
   ; Set up the map projection information to be able to draw on top
   ; of the Google map.
   map = Obj_New('cgMap', 'Mercator', ELLIPSOID='WGS 84', /OnImage)
   uv = map -> Forward(centerLon, centerLat)
   uv_xcenter = uv[0,0]
   uv_ycenter = uv[1,0]
   xrange = [uv_xcenter - (300*scale), uv_xcenter + (300*scale)]
   yrange = [uv_ycenter - (300*scale), uv_ycenter + (300*scale)]
   map -> SetProperty, XRANGE=xrange, YRANGE=yrange
   
   ; Open a window and display the Google Image with a map grid and
   ; location of Coyote's favorite prairie dog restaurant. 
   cgDisplay, 700, 700, Title='OpenStreetMap Image with Coyote Graphics'
   cgImage, mapImage, Position= [50, 50, 650, 650] / 700.
   cgMap_Grid, MAP=map, /BOX_AXES, /cgGRID
   
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  OpenStreetMap_Plot
    
  ; Create a PostScript file.
  cgPS_Open, 'openstreetmap_plot.ps'
  OpenStreetMap_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'openstreetmap_plot.ps', /PNG, /Portrait

END